CustomThemeData class

Constructors

CustomThemeData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

darkThemeData({dynamic data, required bool isTablet}) ThemeData
getPrimaryColor(dynamic data) Color
getSecondaryColor(dynamic data) Color
lightThemeData({dynamic data, required bool isTablet}) ThemeData
selectSize(bool isLarge, double largeSize, double mediumSize) double